package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcBmtb;
import org.apache.ibatis.annotations.Param;

/**
 * 部门通报Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
public interface TcBmtbMapper 
{
    /**
     * 查询部门通报
     * 
     * @param id 部门通报主键
     * @return 部门通报
     */
    public TcBmtb selectTcBmtbById(Long id);

    /**
     * 查询部门通报列表
     * 
     * @param tcBmtb 部门通报
     * @return 部门通报集合
     */
    public List<TcBmtb> selectTcBmtbList(TcBmtb tcBmtb);

    /**
     * 新增部门通报
     * 
     * @param tcBmtb 部门通报
     * @return 结果
     */
    public int insertTcBmtb(TcBmtb tcBmtb);

    /**
     * 修改部门通报
     * 
     * @param tcBmtb 部门通报
     * @return 结果
     */
    public int updateTcBmtb(TcBmtb tcBmtb);

    /**
     * 删除部门通报
     * 
     * @param id 部门通报主键
     * @return 结果
     */
    public int deleteTcBmtbById(Long id);

    /**
     * 批量删除部门通报
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcBmtbByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
