package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcBjsjwp;
import com.ruoyi.tcZz.domain.TcWljg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcBmtb;
import com.ruoyi.tcZz.service.ITcBmtbService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 部门通报Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "部门通报")
@RequestMapping("/tcZz/networkSecurity/bmtb")
public class TcBmtbController extends BaseController
{
    @Autowired
    private ITcBmtbService tcBmtbService;

    /**
     * 查询部门通报列表
     */
    @ApiOperation(value = "查询部门通报列表",response = TcBmtb.class)
    @GetMapping("/list")
    public TableDataInfo list(TcBmtb tcBmtb)
    {
        startPage();
        List<TcBmtb> list = tcBmtbService.selectTcBmtbList(tcBmtb);
        return getDataTable(list);
    }

    /**
     * 导出部门通报列表
     */
    @ApiOperation(value = "导出部门通报列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcBmtb tcBmtb)
    {
        List<TcBmtb> list = tcBmtbService.selectTcBmtbList(tcBmtb);
        ExcelUtil<TcBmtb> util = new ExcelUtil<TcBmtb>(TcBmtb.class);
        util.exportExcel(response, list, "部门通报数据");
    }

    /**
     * 获取部门通报详细信息
     */
    @ApiOperation(value = "获取部门通报详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcBmtbService.selectTcBmtbById(id));
    }

    /**
     * 新增部门通报
     */
    @ApiOperation(value = "新增部门通报")
    @PostMapping
    public AjaxResult add(@RequestBody TcBmtb tcBmtb)
    {
        return toAjax(tcBmtbService.insertTcBmtb(tcBmtb));
    }

    /**
     * 修改部门通报
     */
    @ApiOperation(value = "修改部门通报")
    @PutMapping
    public AjaxResult edit(@RequestBody TcBmtb tcBmtb)
    {
        return toAjax(tcBmtbService.updateTcBmtb(tcBmtb));
    }

    /**
     * 删除部门通报
     */
    @ApiOperation(value = "删除部门通报")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcBmtbService.deleteTcBmtbByIds(ids));
    }

    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcBmtb> util = new ExcelUtil<TcBmtb>(TcBmtb.class);
        List<TcBmtb> tcWljgList = util.importExcel(file.getInputStream());
        tcBmtbService.importUser(tcWljgList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcBmtbService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcBmtb> util = new ExcelUtil<TcBmtb>(TcBmtb.class);
        util.importTemplateExcel(response, " 部门通报");
    }
}
